@@ -268,8 +268,6 @@ class IDP(object):
         self.__dict__['object_names'] = {}
         self.__dict__['cache'] = None
         self.__dict__['dirty'] = True
-        self.Predicate("satisfiable()")
-        self.Constraint("satisfiable()")
         self.init_options()
 
     def init_options(self):
@@ -411,16 +409,23 @@ class IDP(object):
 
         """
         if isa is True:
-            print("ISA GEMAAKT?")
+            if __debug__:
+                print("ISA made")
             res = IDPSpecialType(self, name, enumeration)
         elif constructed_from is True:
             res = IDPConstructedType(self, name, enumeration)
         elif isinstance(enumeration, tuple) and len(enumeration) == 2:
-            range_str = "{:d}..{:d}".format(enumeration[0], enumeration[1])
-            res = IDPIntRangeType(self, name, range_str)
+            range_str = "{}..{}".format(enumeration[0], enumeration[1])
+            if all([isinstance(x, float) for x in enumeration]):
+                res = IDPFloatRangeType(self, name, range_str)
+            else:
+                res = IDPIntRangeType(self, name, range_str)
 
-        elif len(enumeration) > 0 and all([isinstance(x, int)
-                                          for x in enumeration]):
+        elif len(enumeration) > 0 and all([isinstance(x, float) for x in
+                                          enumeration]):
+            res = IDPFloatType(self, name, enumeration)
+        elif len(enumeration) > 0 and all([isinstance(x, int) for x in
+                                          enumeration]):
             res = IDPIntType(self, name, enumeration)
         else:
             res = IDPType(self, name, enumeration)
@@ -489,7 +494,7 @@ class IDP(object):
                                         enumeration, partial=partial)
         else:
             res = IDPUnknownFunction(self, func, arg_list, return_type,
-                                     partial=partial)
+                    partial=partial)
         return self.know(res)
 
     def Constant(self, typed_name, enumeration=None):
@@ -832,7 +837,7 @@ class IDP(object):
             print("SENT TO IDP:")
             print(self.modelexpand_script())
             print("END OF IDP INPUT")
-            f = open('IDPscript.txt', 'w')
+            f = open('IDPscript.idp', 'w')
             f.write(self.modelexpand_script())
             f.close()
             print("SENT TO IDP:")
@@ -853,10 +858,12 @@ class IDP(object):
         sol_list = []
         for model in out:
             if model.strip() == "nil":
-                print("UNSATISFIABLE!")
+                if __debug__:
+                    print("UNSATISFIABLE!")
                 solution = {'satisfiable': False}
             else:
-                print("SATISFIABLE")
+                if __debug__:
+                    print("SATISFIABLE")
                 solution = idp_parse(model, [x.name for x in self.wanted])
                 solution['satisfiable'] = True
             self.dirty = False
@@ -866,7 +873,9 @@ class IDP(object):
     def model_expand(self):
         return self.refresh()
 
-    def minimize(self, term):
+    def minimize(self, term, ssh=False, remote_idp_location=None,
+                 known_hosts_location=None, address=None, username=None,
+                 password=None):
         """
         Run the IDPsystem's minimize and read its output.
         Works by piping to input to the IDP executable, and reading the output.
@@ -879,9 +888,11 @@ class IDP(object):
 
         :param term: the content of the term block, in IDP-form
         :type term: str
+        :param ssh: Can be used to run IDP over SSH
+        :type term: bool
 
         """
-        from subprocess import Popen, PIPE, STDOUT
+        from subprocess import Popen, PIPE, STDOUT, check_output
         import os
 
         termblock = Term(term)  # create a termblock, to minimize term
@@ -889,16 +900,30 @@ class IDP(object):
 
         if __debug__:
             # write it to a file if debug
-            f = open('IDPscript.txt', 'w')
+            f = open('IDPscript.idp', 'w')
             f.write(script)
             f.close()
             print("SENT TO IDP:")
             print(script)
             print("END OF IDP INPUT")
-        idp = Popen(self.executable, stdin=PIPE, stdout=PIPE, stderr=PIPE)
-        out, err = idp.communicate(input=str(script).encode())
-        out = out.decode()  # python3: communicate only works with byte objects
-        err = err.decode()
+        if not ssh:
+            idp = Popen(self.executable, stdin=PIPE, stdout=PIPE, stderr=PIPE)
+            out, err = idp.communicate(input=str(script).encode())
+            out = out.decode()  # python3: communicate only works with byte objects
+            err = err.decode()
+        else:
+            from pyidp3.communicator import communicator
+            print("USING COMMUNICATOR")
+            comm = communicator()
+            comm.remote_idp_location = remote_idp_location
+            comm.known_hosts_location = known_hosts_location
+            comm.address = address
+            comm.username = username
+            comm.password = password
+            out = comm.communicate()
+            if not out:
+                return
+            err = ""
         if err and __debug__:
             print("IDP Error Message:")
             print(err)
@@ -911,14 +936,14 @@ class IDP(object):
         out = out.split("next:")
         for model in out:
             if model.strip() == "nil":
-                print("UNSATISFIABLE!")
+                if __debug__:
+                    print("UNSATISFIABLE!")
                 solution = {'satisfiable': False}
             else:
                 solution = idp_parse(model, [x.name for x in self.wanted])
                 solution['satisfiable'] = True
             self.dirty = False
             sol_list.append(solution)
-        print(len(sol_list))
         return sol_list
 
     def check_sat(self):
@@ -1023,7 +1048,6 @@ class IDP(object):
         return keylist
 
 
-
 def type(idp):
     def foo(cls):
         clsname = cls.__name__
